package cn.reghao.tnb.sb.multi.mybatis.mapper.one;

import cn.reghao.tnb.sb.multi.mybatis.model.one.FileMeta;
import cn.reghao.jutil.jdk.web.db.BaseMapper;

import java.util.List;

/**
 * @author reghao
 * @date 2023-04-13 16:16:00
 */
public interface FileMetaMapper extends BaseMapper<FileMeta> {
    void deleteFileMetas();
    void updateSetDelete(String contentId);
    void updateSetDeleteByObjectId(String objectId);

    List<FileMeta> findByContentId(String contentId);
    FileMeta findByObjectId(String objectId);
    List<FileMeta> findByPrefix();
    List<FileMeta> findByDeleted();
}
